<div class='prefixed-text-input'>
    <input
        type="{{ widget.type }}"
        name="{{ widget.name }}"
        {% if widget.value != None %} value="{{ widget.value|stringformat:'s' }}"{% endif %}
        {% include "django/forms/widgets/attrs.html" %}
        style="--prefix-length: {{ widget.prefix|length }};"
    >
    <span>{{ widget.prefix }}</span>
</div>
